==> audacious_3.2.1.orig.tar.bz2: audacious-3.2.1/src/audacious/drct-api.h <==
/*
 * drct-api.h
 * Copyright 2010-2011 John Lindgren
 *
 * This file is part of Audacious.
 *
 * Audacious is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, version 2 or version 3 of the License.
 *
 * Audacious is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Audacious. If not, see <http://www.gnu.org/licenses/>.
 *
 * The Audacious team does not consider modular code linking to Audacious or
 * using our public API to be a derived work.
 */

/* Do not include this file directly; use drct.h instead. */

/* CAUTION: These functions are not thread safe. */

/* --- PROGRAM CONTROL --- */

AUD_VFUNC0 (drct_quit)

/* --- PLAYBACK CONTROL --- */

/* The strings returned by drct_get_filename() and drct_get_title() are pooled
 * and must be freed with str_unref(). */

AUD_VFUNC0 (drct_play)
AUD_VFUNC0 (drct_pause)
AUD_VFUNC0 (drct_stop)
AUD_FUNC0 (bool_t, drct_get_playing)
AUD_FUNC0 (bool_t, drct_get_ready)
AUD_FUNC0 (bool_t, drct_get_paused)
AUD_FUNC0 (char *, drct_get_filename)
AUD_FUNC0 (char *, drct_get_title)
AUD_VFUNC3 (drct_get_info, int *, bitrate, int *, samplerate, int *, channels)
AUD_FUNC0 (int, drct_get_time)
AUD_FUNC0 (int, drct_get_length)
AUD_VFUNC1 (drct_seek, int, time)

/* --- VOLUME CONTROL --- */

AUD_VFUNC2 (drct_get_volume, int *, left, int *, right)
AUD_VFUNC2 (drct_set_volume, int, left, int, right)
AUD_VFUNC1 (drct_get_volume_main, int *, volume)
AUD_VFUNC1 (drct_set_volume_main, int, volume)
AUD_VFUNC1 (drct_get_volume_balance, int *, balance)
AUD_VFUNC1 (drct_set_volume_balance, int, balance)

/* --- PLAYLIST CONTROL --- */

/* The indexes passed to drct_pl_add_list(), drct_pl_open_list(), and
 * drct_pl_open_temp_list() contain pooled strings to which the caller gives up
 * one reference.  The indexes themselves are freed by these functions. */

AUD_VFUNC0 (drct_pl_next)
AUD_VFUNC0 (drct_pl_prev)

AUD_VFUNC2 (drct_pl_add, const char *, filename, int, at)
AUD_VFUNC2 (drct_pl_add_list, Index *, filenames, int, at)
AUD_VFUNC1 (drct_pl_open, const char *, filename)
AUD_VFUNC1 (drct_pl_open_list, Index *, filenames)
AUD_VFUNC1 (drct_pl_open_temp, const char *, filename)
AUD_VFUNC1 (drct_pl_open_temp_list, Index *, filenames)

AUD_VFUNC1 (drct_pl_delete_selected, int, playlist)

==> audacious_3.4.3.orig.tar.bz2: audacious-3.4.3/src/audacious/drct-api.h <==
/*
 * drct-api.h
 * Copyright 2010-2011 John Lindgren
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions, and the following disclaimer in the documentation
 *    provided with the distribution.
 *
 * This software is provided "as is" and without any warranty, express or
 * implied. In no event shall the authors be liable for any damages arising from
 * the use of this software.
 */

/* Do not include this file directly; use drct.h instead. */

/* CAUTION: These functions are not thread safe. */

/* --- PROGRAM CONTROL --- */

AUD_VFUNC0 (drct_quit)

/* --- PLAYBACK CONTROL --- */

/* The strings returned by drct_get_filename() and drct_get_title() are pooled
 * and must be freed with str_unref(). */

AUD_VFUNC0 (drct_play)
AUD_VFUNC1 (drct_play_playlist, int, playlist)
AUD_VFUNC0 (drct_pause)
AUD_VFUNC0 (drct_stop)
AUD_FUNC0 (bool_t, drct_get_playing)
AUD_FUNC0 (bool_t, drct_get_ready)
AUD_FUNC0 (bool_t, drct_get_paused)
AUD_FUNC0 (char *, drct_get_filename)
AUD_FUNC0 (char *, drct_get_title)
AUD_VFUNC3 (drct_get_info, int *, bitrate, int *, samplerate, int *, channels)
AUD_FUNC0 (int, drct_get_time)
AUD_FUNC0 (int, drct_get_length)
AUD_VFUNC1 (drct_seek, int, time)

/* --- VOLUME CONTROL --- */

AUD_VFUNC2 (drct_get_volume, int *, left, int *, right)
AUD_VFUNC2 (drct_set_volume, int, left, int, right)
AUD_VFUNC1 (drct_get_volume_main, int *, volume)
AUD_VFUNC1 (drct_set_volume_main, int, volume)
AUD_VFUNC1 (drct_get_volume_balance, int *, balance)
AUD_VFUNC1 (drct_set_volume_balance, int, balance)

/* --- PLAYLIST CONTROL --- */

/* The indexes passed to drct_pl_add_list(), drct_pl_open_list(), and
 * drct_pl_open_temp_list() contain pooled strings to which the caller gives up
 * one reference.  The indexes themselves are freed by these functions. */

AUD_VFUNC0 (drct_pl_next)
AUD_VFUNC0 (drct_pl_prev)

AUD_VFUNC2 (drct_pl_add, const char *, filename, int, at)
AUD_VFUNC2 (drct_pl_add_list, Index *, filenames, int, at)
AUD_VFUNC1 (drct_pl_open, const char *, filename)
AUD_VFUNC1 (drct_pl_open_list, Index *, filenames)
AUD_VFUNC1 (drct_pl_open_temp, const char *, filename)
AUD_VFUNC1 (drct_pl_open_temp_list, Index *, filenames)

/* deprecated; use playlist_delete_selected() */
AUD_VFUNC1 (drct_pl_delete_selected, int, playlist)

/* added in Audacious 3.4 */

/* "A-B repeat": when playback reaches point B, it returns to point A (where A
 * and B are in milliseconds).  The value -1 is interpreted as the beginning of
 * the song (for A) or the end of the song (for B).  A-B repeat is disabled
 * entirely by setting both A and B to -1. */
AUD_VFUNC2 (drct_set_ab_repeat, int, a, int, b)
AUD_VFUNC2 (drct_get_ab_repeat, int *, a, int *, b)

AUD_VFUNC0 (drct_play_pause)
